@@ -3,18 +3,18 @@ package proxy
 import (
 	"errors"
 	"fmt"
-	io2 "github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/pkg/zeroalloc/io"
-	"inet.af/netaddr"
+	io2 "github.com/mzz2017/softwind/pkg/zeroalloc/io"
 	"net"
+	"net/netip"
 	"time"
 )
 
 func (p *Proxy) handleTCP(conn net.Conn) error {
 	defer conn.Close()
-	loopback, _ := netaddr.FromStdIP(conn.LocalAddr().(*net.TCPAddr).IP)
+	loopback, _ := netip.AddrFromSlice(conn.LocalAddr().(*net.TCPAddr).IP)
 	tgt := p.GetProjection(loopback)
 	if tgt == "" {
-		return fmt.Errorf("mapped target address not found")
+		return fmt.Errorf("mapped target address not found: %v", loopback)
 	}
 	p.log.Tracef("received tcp: %v, tgt: %v", conn.RemoteAddr().String(), tgt)
 	c, err := p.dialer.Dial("tcp", tgt)
